@@ -10,11 +10,12 @@ Module::Starter - a simple starter kit for any module
 
 =head1 VERSION
 
-Version 1.58
+Version 1.71_01
 
 =cut
 
-our $VERSION = '1.58_03';
+our $VERSION = '1.71_01';
+$VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
 
@@ -53,10 +54,11 @@ It takes a hash of params, as follows:
                                       # or specify more than one builder in an
                                       # arrayref
 
-    license      => $license,  # type of license; defaults to 'perl'
-    author       => $author,   # author's full name (required)
-    email        => $email,    # author's email address (required)
-    ignores_type => $type,     # ignores file type ('generic', 'cvs', 'git', 'manifest' )
+    license      => $license,  # type of license; defaults to 'artistic2'
+    author       => $author,   # author's full name (taken from C<getpwuid> if not provided)
+    email        => $email,    # author's email address (taken from C<EMAIL> if not provided)
+    ignores_type => $type,     # ignores file type ('generic', 'cvs', 'git', 'hg', 'manifest' )
+    fatalize     => $fatalize, # generate code that makes warnings fatal
 
     verbose      => $verbose,  # bool: print progress messages; defaults to 0
     force        => $force     # bool: overwrite existing files; defaults to 0
@@ -67,6 +69,7 @@ These are the mappings:
     ignores_type => 'generic'  # default, creates 'ignore.txt'
     ignores_type => 'cvs'      # creates .cvsignore
     ignores_type => 'git'      # creates .gitignore
+    ignores_type => 'hg'       # creates .hgignore
     ignores_type => 'manifest' # creates MANIFEST.SKIP
 
 It is also possible to provide an array ref with multiple types wanted:
@@ -139,24 +142,24 @@ L<http://annocpan.org/dist/Module-Starter>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/Module-Starter>
+L<http://cpanratings.perl.org/dist/Module-Starter>
 
-=item * RT: CPAN's request tracker
+=item * GitHub issue tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Module-Starter>
+L<https://github.com/xsawyerx/module-starter/issues>
 
-=item * Search CPAN
+=item * Metacpan
 
-L<http://search.cpan.org/dist/Module-Starter>
+L<https://metacpan.org/release/Module-Starter>
 
 =back
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<bug-module-starter at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to the bugtracker for this project
+on GitHub at: L<https://github.com/xsawyerx/module-starter/issues>. I will be
+notified, and then you'll automatically be notified of progress on your bug
+as I make changes.
 
 =head1 COPYRIGHT
 
