@@ -9,9 +9,10 @@ Module::Starter::App - the code behind the command line program
 use warnings;
 use strict;
 
-our $VERSION = '1.58_03';
+our $VERSION = '1.71_01';
+$VERSION = eval $VERSION;
 
-use Path::Class;
+use File::Spec;
 use Getopt::Long;
 use Pod::Usage;
 use Carp qw( croak );
@@ -21,10 +22,10 @@ sub _config_file {
     my $configdir = $ENV{'MODULE_STARTER_DIR'} || '';
 
     if ( !$configdir && $ENV{'HOME'} ) {
-        $configdir = dir( $ENV{'HOME'}, '.module-starter' );
+        $configdir = File::Spec->catdir( $ENV{'HOME'}, '.module-starter' );
     }
 
-    return file( $configdir, 'config' );
+    return File::Spec->catfile( $configdir, 'config' );
 }
 
 
@@ -82,6 +83,8 @@ sub _process_command_line {
         'email=s'    => \$config{email},
         'license=s'  => \$config{license},
         'minperl=s'  => \$config{minperl},
+        'fatalize'   => \$config{fatalize},
+
         force        => \$config{force},
         verbose      => \$config{verbose},
         version      => sub {
