@@ -17,11 +17,12 @@ Module::Starter::Simple - a simple, comprehensive Module::Starter plugin
 
 =head1 VERSION
 
-Version 1.58
+Version 1.71_01
 
 =cut
 
-our $VERSION = '1.58_03';
+our $VERSION = '1.71_01';
+$VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
 
@@ -93,12 +94,20 @@ sub create_distro {
         croak "Invalid module name: $_" unless /\A[a-z_]\w*(?:::[\w]+)*\Z/i;
     }
 
+    if ( ( not $self->{author} ) && ( $^O ne 'MSWin32' ) ) {
+        ( $self->{author} ) = split /,/, ( getpwuid $> )[6];
+    }
+
+    if ( not $self->{email} and exists $ENV{EMAIL} ) {
+        $self->{email} = $ENV{EMAIL};
+    }
+
     croak "Must specify an author\n" unless $self->{author};
     croak "Must specify an email address\n" unless $self->{email};
     ($self->{email_obfuscated} = $self->{email}) =~ s/@/ at /;
 
     $self->{license}      ||= 'artistic2';
-    $self->{minperl}      ||= 5.006;
+    $self->{minperl}      ||= '5.006';
     $self->{ignores_type} ||= ['generic'];
     $self->{manifest_skip} = !! grep { /manifest/ } @{ $self->{ignores_type} };
     
@@ -220,7 +229,7 @@ method eventually.)
 our $LICENSES = {
     perl => {
         license => 'perl',
-        slname  => 'Perl_5',
+        slname  => 'perl_5',
         url     => 'http://dev.perl.org/licenses/',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or modify it
@@ -232,7 +241,7 @@ EOT
     },
     artistic => {
         license => 'artistic',
-        slname  => 'Artistic_1_0',
+        slname  => 'artistic_1',
         url     => 'http://www.perlfoundation.org/artistic_license_1_0',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or modify it
@@ -258,7 +267,7 @@ EOT
     },
     artistic2 => {
         license => 'artistic2',
-        slname  => 'Artistic_2_0',
+        slname  => 'artistic_2',
         url     => 'http://www.perlfoundation.org/artistic_license_2_0',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or modify it
@@ -300,7 +309,7 @@ EOT
     },
     mit => {
         license => 'mit',
-        slname  => 'MIT',
+        slname  => 'mit',
         url     => 'http://www.opensource.org/licenses/mit-license.php',
         blurb   => <<'EOT',
 This program is distributed under the MIT (X11) License:
@@ -330,7 +339,7 @@ EOT
     },
     mozilla => {
         license => 'mozilla',
-        slname  => 'Mozilla_1_1',
+        slname  => 'mozilla_1_1',
         url     => 'http://www.mozilla.org/MPL/1.1/',
         blurb   => <<'EOT',
 The contents of this file are subject to the Mozilla Public License
@@ -346,7 +355,7 @@ EOT
     },
     mozilla2 => {
         license => 'mozilla2',
-        slname  => 'Mozilla_2_0',
+        slname  => 'open_source',
         url     => 'http://www.mozilla.org/MPL/2.0/',
         blurb   => <<'EOT',
 This Source Code Form is subject to the terms of the Mozilla Public
@@ -356,7 +365,7 @@ EOT
     },
     bsd => {
         license => 'bsd',
-        slname  => 'BSD',
+        slname  => 'bsd',
         url     => 'http://www.opensource.org/licenses/BSD-3-Clause',
         blurb   => <<"EOT",
 This program is distributed under the (Revised) BSD License:
@@ -393,7 +402,7 @@ EOT
     },
     freebsd => {
         license => 'freebsd',
-        slname  => 'FreeBSD',
+        slname  => 'freebsd',
         url     => 'http://www.opensource.org/licenses/BSD-2-Clause',
         blurb   => <<"EOT",
 This program is distributed under the (Simplified) BSD License:
@@ -425,7 +434,7 @@ EOT
     },
     cc0 => {
         license => 'cc0',
-        slname  => 'CC0',
+        slname  => 'unrestricted',
         url     => 'http://creativecommons.org/publicdomain/zero/1.0/',
         blurb   => <<'EOT',
 This program is distributed under the CC0 1.0 Universal License:
@@ -457,7 +466,7 @@ EOT
     },
     gpl => {
         license => 'gpl',
-        slname  => 'GPL_2',
+        slname  => 'gpl_2',
         url     => 'http://www.gnu.org/licenses/gpl-2.0.html',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or modify
@@ -472,12 +481,12 @@ GNU General Public License for more details.
 
 A copy of the GNU General Public License is available in the source tree;
 if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 EOT
     },
     lgpl => {
         license => 'lgpl',
-        slname  => 'LGPL_2',
+        slname  => 'lgpl_2_1',
         url     => 'http://www.gnu.org/licenses/lgpl-2.1.html',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or
@@ -492,13 +501,13 @@ Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
 License along with this program; if not, write to the Free
-Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-02111-1307 USA.
+Software Foundation, Inc.,
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 EOT
     },
     gpl3 => {
         license => 'gpl3',
-        slname  => 'GPL_3',
+        slname  => 'gpl_3',
         url     => 'http://www.gnu.org/licenses/gpl-3.0.html',
         blurb   => <<'EOT',
 This program is free software: you can redistribute it and/or modify
@@ -517,7 +526,7 @@ EOT
     },
     lgpl3 => {
         license => 'lgpl3',
-        slname  => 'LGPL_3',
+        slname  => 'lgpl_3_0',
         url     => 'http://www.gnu.org/licenses/lgpl-3.0.html',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or
@@ -537,7 +546,7 @@ EOT
     },
     agpl3 => {
         license => 'agpl3',
-        slname  => 'AGPL_2',
+        slname  => 'agpl_3',
         url     => 'http://www.gnu.org/licenses/agpl-3.0.html',
         blurb => <<'EOT',
 This program is free software; you can redistribute it and/or
@@ -557,7 +566,7 @@ EOT
     },
     apache => {
         license => 'apache',
-        slname  => 'Apache_2_0',
+        slname  => 'apache_2_0',
         url     => 'http://www.apache.org/licenses/LICENSE-2.0',
         blurb   => <<'EOT',
 Licensed under the Apache License, Version 2.0 (the "License");
@@ -575,7 +584,7 @@ EOT
     },
     qpl => {
         license => 'qpl',
-        slname  => 'QPL_1_0',
+        slname  => 'qpl_1_0',
         url     => 'http://www.opensource.org/licenses/QPL-1.0',
         blurb   => <<'EOT',
 This program is distributed under the Q Public License (QPL-1.0):
@@ -745,10 +754,12 @@ sub Makefile_PL_guts {
     
     my $slname = $self->{license_record} ? $self->{license_record}->{slname} : $self->{license};
 
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
+
     return <<"HERE";
 use $self->{minperl};
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 use ExtUtils::MakeMaker;
 
 WriteMakefile(
@@ -758,16 +769,16 @@ WriteMakefile(
     ABSTRACT_FROM    => '$main_pm_file',
     LICENSE          => '$slname',
     PL_FILES         => {},
-    MIN_PERL_VERSION => $self->{minperl},
+    MIN_PERL_VERSION => '$self->{minperl}',
     CONFIGURE_REQUIRES => {
-        'ExtUtils::MakeMaker' => 0,
+        'ExtUtils::MakeMaker' => '0',
     },
     BUILD_REQUIRES => {
-        'Test::More' => 0,
+        'Test::More' => '0',
     },
     PREREQ_PM => {
-        #'ABC'              => 1.6,
-        #'Foo::Bar::Module' => 5.0401,
+        #'ABC'              => '1.6',
+        #'Foo::Bar::Module' => '5.0401',
     },
     dist  => { COMPRESS => 'gzip -9f', SUFFIX => 'gz', },
     clean => { FILES => '$self->{distro}-*' },
@@ -794,10 +805,12 @@ sub MI_Makefile_PL_guts {
     
     my $license_url = $self->{license_record} ? $self->{license_record}->{url} : '';
 
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
+
     return <<"HERE";
 use $self->{minperl};
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 use inc::Module::Install;
 
 name     '$self->{distro}';
@@ -805,7 +818,7 @@ all_from '$main_pm_file';
 author   q{$author};
 license  '$self->{license}';
 
-perl_version $self->{minperl};
+perl_version '$self->{minperl}';
 
 tests_recursive('t');
 
@@ -814,20 +827,21 @@ resources (
    #IRC        => 'irc://irc.perl.org/#$self->{distro}',
    license    => '$license_url',
    #repository => 'git://github.com/$self->{author}/$self->{distro}.git',
+   #repository => 'https://bitbucket.org/$self->{author}/$self->{distro}',
    bugtracker => 'http://rt.cpan.org/NoAuth/Bugs.html?Dist=$self->{distro}',
 );
 
 configure_requires (
-   'Module::Install' => 0,
+   'Module::Install' => '0',
 );
 
 build_requires (
-   'Test::More' => 0,
+   'Test::More' => '0',
 );
 
 requires (
-   #'ABC'              => 1.6,
-   #'Foo::Bar::Module' => 5.0401,
+   #'ABC'              => '1.6',
+   #'Foo::Bar::Module' => '5.0401',
 );
 
 install_as_cpan;
@@ -882,10 +896,12 @@ sub Build_PL_guts {
 
     my $slname = $self->{license_record} ? $self->{license_record}->{slname} : $self->{license};
     
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
+
     return <<"HERE";
 use $self->{minperl};
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 use Module::Build;
 
 my \$builder = Module::Build->new(
@@ -895,17 +911,16 @@ my \$builder = Module::Build->new(
     dist_version_from   => '$main_pm_file',
     release_status      => 'stable',
     configure_requires => {
-        'Module::Build' => 0,
+        'Module::Build' => '0',
     },
     build_requires => {
-        'Test::More' => 0,
+        'Test::More' => '0',
     },
     requires => {
-        #'ABC'              => 1.6,
-        #'Foo::Bar::Module' => 5.0401,
+        #'ABC'              => '1.6',
+        #'Foo::Bar::Module' => '5.0401',
     },
     add_to_cleanup     => [ '$self->{distro}-*' ],
-    create_makefile_pl => 'traditional',
 );
 
 \$builder->create_build_script();
@@ -1065,9 +1080,12 @@ sub create_t {
     my $self = shift;
     my @modules = @_;
 
-    my %t_files = $self->t_guts(@modules);
+    my %t_files  = $self->t_guts(@modules);
+    my %xt_files = $self->xt_guts(@modules);
 
-    my @files = map { $self->_create_t($_, $t_files{$_}) } keys %t_files;
+    my @files;
+    push @files, map { $self->_create_t('t',  $_, $t_files{$_}) }  keys %t_files;
+    push @files, map { $self->_create_t('xt', $_, $xt_files{$_}) } keys %xt_files;
 
     return @files;
 }
@@ -1088,16 +1106,22 @@ sub t_guts {
 
     my %t_files;
     my $minperl = $self->{minperl};
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
+
     my $header = <<"EOH";
 #!perl -T
 use $minperl;
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 use Test::More;
 
 EOH
     
     $t_files{'pod.t'} = $header.<<'HERE';
+unless ( $ENV{RELEASE_TESTING} ) {
+    plan( skip_all => "Author tests not required for installation" );
+}
+
 # Ensure a recent version of Test::Pod
 my $min_tp = 1.22;
 eval "use Test::Pod $min_tp";
@@ -1119,6 +1143,10 @@ ok_manifest();
 HERE
 
     $t_files{'pod-coverage.t'} = $header.<<'HERE';
+unless ( $ENV{RELEASE_TESTING} ) {
+    plan( skip_all => "Author tests not required for installation" );
+}
+
 # Ensure a recent version of Test::Pod::Coverage
 my $min_tpc = 1.08;
 eval "use Test::Pod::Coverage $min_tpc";
@@ -1151,12 +1179,42 @@ $use_lines
 diag( "Testing $main_module \$${main_module}::VERSION, Perl \$], \$^X" );
 HERE
 
+    return %t_files;
+}
+
+=head2 xt_guts( @modules )
+
+This method is called by create_t, and returns a description of the author
+only *.t files to be created in the xt directory.
+
+The return value is a hash of test files to create.  Each key is a filename and
+each value is the contents of that file.
+
+=cut
+
+sub xt_guts {
+    my $self = shift;
+    my @modules = @_;
+
+    my %xt_files;
+    my $minperl = $self->{minperl};
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
+
+    my $header = <<"EOH";
+#!perl -T
+use $minperl;
+use strict;
+use $warnings
+use Test::More;
+
+EOH
+
     my $module_boilerplate_tests;
     $module_boilerplate_tests .=
       "  module_boilerplate_ok('".$self->_module_to_pm_file($_)."');\n" for @modules;
 
     my $boilerplate_tests = @modules + 2 + $[;
-    $t_files{'boilerplate.t'} = $header.<<"HERE";
+    $xt_files{'boilerplate.t'} = $header.<<"HERE";
 plan tests => $boilerplate_tests;
 
 sub not_in_file_ok {
@@ -1209,15 +1267,16 @@ $module_boilerplate_tests
 
 HERE
 
-    return %t_files;
+    return %xt_files;
 }
 
 sub _create_t {
     my $self = shift;
+    my $directory = shift;  # 't' or 'xt'
     my $filename = shift;
     my $content = shift;
 
-    my @dirparts = ( $self->{basedir}, 't' );
+    my @dirparts = ( $self->{basedir}, $directory );
     my $tdir = File::Spec->catdir( @dirparts );
     if ( not -d $tdir ) {
         local @ARGV = $tdir;
@@ -1229,7 +1288,7 @@ sub _create_t {
     $self->create_file( $fname, $content );
     $self->progress( "Created $fname" );
 
-    return "t/$filename";
+    return join('/', $directory, $filename );
 }
 
 =head2 create_MB_MANIFEST
@@ -1295,7 +1354,7 @@ sub create_MANIFEST {
     $self->$manifest_method();
     $self->filter_lines_in_file(
         $fname,
-        qr/^t\/boilerplate\.t$/,
+        qr/^xt\/boilerplate\.t$/,
         qr/^ignore\.txt$/,
     );
 
@@ -1402,6 +1461,7 @@ sub create_ignores {
         generic  => 'ignore.txt',
         cvs      => '.cvsignore',
         git      => '.gitignore',
+        hg       => '.hgignore',
         manifest => 'MANIFEST.SKIP',
     );
 
@@ -1456,7 +1516,7 @@ pm_to_blib
 $self->{distro}-*
 $self->{distro}-*.tar.gz
 EOF
-        # make this more restrictive, since MANIFEST tends to be less noticable
+        # make this more restrictive, since MANIFEST tends to be less noticeable
         # (also, manifest supports REs.)
         manifest => <<'EOF',
 # Top-level filter (only include the following...)
@@ -1468,7 +1528,7 @@ EOF
 ,v$
 \B\.svn\b
 \b_darcs\b
-# (.git only in top-level, hence it's blocked above)
+# (.git or .hg only in top-level, hence it's blocked above)
 
 # Avoid temp and backup files.
 ~$
@@ -1491,7 +1551,7 @@ EOF
 \.rej$
 EOF
     };
-    $guts->{cvs} = $guts->{git} = $guts->{generic};
+    $guts->{hg} = $guts->{cvs} = $guts->{git} = $guts->{generic};
     
     return $guts->{$type};
 }
@@ -1573,10 +1633,10 @@ sub filter_lines_in_file {
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<bug-module-starter at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically
-be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to the bugtracker for this project
+on GitHub at: L<https://github.com/xsawyerx/module-starter/issues>. I will be
+notified, and then you'll automatically be notified of progress on your bug
+as I make changes.
 
 =head1 AUTHOR
 
@@ -1604,12 +1664,14 @@ sub _module_header {
     my $self = shift;
     my $module = shift;
     my $rtname = shift;
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all'" : '');
+
     my $content = <<"HERE";
 package $module;
 
 use $self->{minperl};
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 
 \=head1 NAME
 
